@@ -1,6 +1,7 @@
 from cursesplus import *
 from cursesplus import filedialog
 from cursesplus import progressbars
+import cursesplus
 import cursesplus.messagebox
 
 def __test__(stdscr):
@@ -15,12 +16,13 @@ def __test__(stdscr):
         #p.appendlog(str(i),curses.color_pair(random.randint(1,12)))
     #p.done()
     #del p
-    #displaymsg(stdscr,[filedialog.openfiledialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]])])
+    displaymsg(stdscr,[filedialog.openfiledialog(stdscr)])
     #displaymsg(stdscr,str(cursesinput(stdscr,"HI").endswith(" ")))
     #displaymsg(stdscr,filedialog.openfilesdialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]]))
     #progressbars.readfile_progress_bar(stdscr,"/usr/bin/gcc")
     #progressbars.writefile_progress_bar(stdscr,"bytes.txt","".join([chr(random.randint(0,255)) for _ in range(1000000)]).encode())
-    cursesplus.messagebox.askyesno(stdscr,message=["AMCS OOBE","","Would you like to set up a server now","Or skip the OOBE?"])
+    #cursesplus.messagebox.askyesno(stdscr,message=["AMCS OOBE","","Would you like to set up a server now","Or skip the OOBE?"])
+    #cursesplus.cursestransition(stdscr,type=1)
 
 if __name__ == "__main__":
     #Testing things
