@@ -13,7 +13,7 @@ def readfile_progress_bar(stdscr,path: str) -> bytes:
             p.step(f"Read {len(data)} bytes")
             lx += 1
             
-    p.done()
+    #p.done()
     return data
 
 def writefile_progress_bar(stdscr,path: str,data: bytes):
@@ -27,4 +27,8 @@ def writefile_progress_bar(stdscr,path: str,data: bytes):
             p.step(f"Writing {len(data)} bytes")
             f.write(line)
             f.write(b"\n")
-    p.done()
\ No newline at end of file
+    #p.done()
+"""
+def copyfile_progress_bar(stdscr,src: str,dest:str) -> None:
+    p = cp.ProgressBar(stdcrr)
+"""
\ No newline at end of file
